@@ -330,6 +330,8 @@ class LPMain:
         Parameters:
         path (str): The file path where the Excel file should be saved.
         '''
+        if not path.endswith('.xlsx'):
+            path+='.xlsx'
         import pandas as pd
         with pd.ExcelWriter(path,engine='openpyxl') as writer:
             for obj in self.obj_lst:
